@@ -1,5 +1,5 @@
 package PAR;
-$PAR::VERSION = '0.977';
+$PAR::VERSION = '0.979';
 
 use 5.006;
 use strict;
@@ -32,7 +32,7 @@ PAR - Perl Archive Toolkit
 
 =head1 VERSION
 
-This document describes version 0.977 of PAR, released October 19, 2007.
+This document describes version 0.979 of PAR, released May 13, 2008.
 
 =head1 SYNOPSIS
 
@@ -88,6 +88,9 @@ Use in a program:
     # PAR::read_file() returns a file inside any loaded PARs
     my $conf = PAR::read_file('data/MyConfig.yaml');
 
+    # PAR::get_filehandle() returns an fh for a file inside any loaded PARs
+    my $largeFile = PAR::get_filehandle('data/MyConfig.xml');
+
     # PAR::par_handle() returns an Archive::Zip handle
     my $zip = PAR::par_handle('foo.par')
     my $src = $zip->memberNamed('lib/Hello.pm')->contents;
@@ -687,6 +690,17 @@ sub reload_libs {
     }
 }
 
+sub get_filehandle {
+    my $file = pop;
+
+    foreach my $zip (@LibCache) {
+        my $member = _first_member($zip, $file) or next;
+        return $member->fh();
+    }
+
+    return;
+}
+
 sub read_file {
     my $file = pop;
 
@@ -1116,7 +1130,7 @@ preferred.
 
 =head1 COPYRIGHT
 
-Copyright 2002-2007 by Audrey Tang
+Copyright 2002-2008 by Audrey Tang
 E<lt>cpan@audreyt.orgE<gt>.
 
 This program is free software; you can redistribute it and/or modify it
